+++
date = "2020-10-27T14:53:59Z"
title = "Science"
type = "article"
draft = false
+++

## Scientific Targets

The KM3NeT neutrino detectors will continuously register neutrinos from the whole sky. The neutrinos of astrophysical interest, i.e. those from extra-terrestrial origin, need to be identified in the background of atmospheric neutrinos, i.e. those created in Earth’s atmosphere by interactions of cosmic-ray particles. Access to cosmic neutrino data is of high importance for a wide astrophysics community to relate cosmic neutrino fluxes to observations by other neutrino observatories or using [other messengers](Multimessengers.md), and to compare them with theoretical predictions. The atmospheric neutrinos carry information on the particle physics processes in which they are created and on the neutrinos themselves. These data are relevant for a wide astroparticle and particle physics community. Finally, KM3NeT will monitor marine parameters, such as bioluminescence, currents, water properties and transient acoustic signals and provides user ports for Earth and Sea sciences.


### Astro Physics

The main science objective of KM3NeT/ARCA is the detection of high-energy neutrinos of cosmic origin. Neutrinos represent an alternative to photons and cosmic rays to explore the high-energy Universe. Neutrinos can emerge from dense objects and travel large distances, without being deflected by magnetic fields or interacting with radiation and matter. Thus, even modest numbers of detected neutrinos can be of utmost scientific relevance, by indicating the astrophysical objects in which cosmic rays are accelerated, or pointing to places where dark matter particles annihilate or decay. 

The detector design of the KM3NeT/ARCA has been optimised to target astrophysical neutrinos at TeV energies and above in order to maximise the sensitivity to detect neutrinos from the cosmic ray accelerators in our Galaxy. In a neutrino telescope like ARCA, two main event topologies can be identified: Firstly, the 'track' topology indicates the presence of muons produced in charged current muon neutrino interactions and tau neutrino interactions with muonic tau decays. Muons are the only class of particles that can be confidently identified, because they are the only particles that appear as tracks in the detector. Secondly, the shower topology refers to a point-like particle shower from neutral current interactions of all three neutrino flavours, the charge current interactions of electron neutrino and tau neutrino interactions with non-muonic tau decays. For tau neutrinos at sufficiently high energies (E > 100TeV), the produced tau lepton can travel several metres before decaying, resulting in distinguishable two individual showers. This allows identification of tau neutrinos with a clear signature of the flavour of the neutrino primaries. All neutrino flavours can be used for neutrino astronomy.

The preferred search strategy is to identify upward-moving tracks, which unambiguously indicates neutrino reactions since only neutrinos can traverse the Earth without being absorbed. A neutrino telescope in the Mediterranean Sea on the Northern hemisphere of the Earth is well suited for this purpose, since most of the potential Galactic sources are in the Southern sky. 

Besides all-favour neutrino astronomy, i.e. investigating high-energy cosmic neutrinos and identifying their astrophysical sources, additional physics topics of ARCA include

- [multi-messenger studies](Multimessengers.md)
- particle physics with atmospheric muons and neutrinos
- indirect searches for dark matter

The ARCA detector allows to reconstruct the arrival direction of TeV-PeV neutrinos to sub-degree resolution for track-like events and ~2 degree for shower-like events. The energy resolution is about ~0.27 in log10(E_\mu) for muons above 10TeV, while for showers a ~5% resolution on the visible energy is achieved. In order to achieve these resolutions, typically a set of quality selection criteria are applied based on the output of the event reconstructions. 

Further details on the detector performance can be found [here](https://iopscience.iop.org/article/10.1088/0954-3899/43/8/084001).


### Neutrino Physics

Neutrinos have the peculiar feature that they can change from one flavour to another when propagating over macroscopic distances. This phenomenon of neutrino flavour change is known as 'neutrino oscillation'. The Nobel Prize in Physics of the year 2015 was awarded to T. Kajita and A. B. McDonald for the discovery of neutrino oscillations, which shows that neutrinos have mass [1]. One open question is the so-called 'neutrino mass ordering'. It refers to the sign of one of the two independent neutrino mass differences, the absolute value of which has already been known for more than two decades.

The main science objective of KM3NeT/ORCA is the determination of the ordering of the three neutrino mass eigenstates by measuring the oscillation pattern of atmospheric neutrinos. Atmospheric neutrinos are produced in cosmic-ray air-showers in the Earth atmosphere. When produced on the other side of the Earth and traversing the Earth towards the detector, atmospheric neutrinos oscillate, ie. change their flavour between production and detection. The oscillation pattern in the few-GeV energy range is sensitive to the neutrino mass ordering and other oscillation parameters.

Besides determining the neutrino mass ordering, additional science topics of ORCA include:

- testing the unitary of the neutrino mixing matrix by studying tau-neutrino appearance
- indirect searches for sterile neutrinos, non-standard interactions and other exotic physics
- indirect searches for dark matter; testing the chemical composition of the Earth's core (Earth tomography)
- low-energy neutrino astrophysics

The detector design of the KM3NeT/ORCA has been optimised for atmospheric neutrinos in the 1-100GeV energy range in order to maximise the sensitivity of determining the neutrino mass ordering. For neutrino oscillation measurements with KM3NeT/ORCA, the capability to differentiate the two event topologies -- i.e. the track-shower separation power -- is very important.

The detector performance of the ORCA detector is summarised in detail [here](https://iopscience.iop.org/article/10.1088/0954-3899/43/8/084001)    


### Multi-Messenger Astrophysics

The multi-messenger approach in astrophysics means looking for at least two or more cosmic messenger particles to study the transient phenomena in our Universe, such as gamma-ray burst, the outburst of active galactic nuclei, fast radio burst, supernova explosion, etc. Using multiple messengers greatly extends our understanding of the Universe compared to using one single channel. The cosmic messengers include electromagnetic waves, cosmic rays, gravitational waves, and neutrinos. 

Some of the most important open questions in astrophysics are the origin of astrophysical neutrinos, the origin of cosmic rays, acceleration mechanics of high energy cosmic rays, etc. Multi-messenger studies can help answer these questions.

Up to now, there are three successful multi-messenger detections: 

1) In 1987, the observation of the supernova 1987A, where neutrinos are observed in neutrino experiments about 2 or 3 hours before the visual observations. 
2) 30 years later in 2017, the observation of the gravitational wave and the electromagnetic observations of the gamma-ray burst observed by Fermi and Integral. 
3) TXS 0506, where for the first time, blazars are identified as a neutrino source. 

#### Importance of Neutrinos for Multi-Messenger Studies

Among those multiple messengers, neutrinos are an important type of messenger. Neutrinos are neutral and only interact via gravity and weak interactions. Neutrinos point back to their sources where they were created.

For example, cosmic rays are charged particles, thus they are deflected by the galactic magnetic fields. Cosmic ray observatories can detect them but their observed arrival directions do not point back to their sources. During the propagation of cosmic rays, neutrinos are produced during the interaction of cosmic rays and the extragalactic background light. Since neutrinos are not bent by magnetic fields, they can act as good tracers for studying the propagation of cosmic rays.

Looking for coincidences of neutrinos and electromagnetic or GW counterparts may also reveal subthreshold events that otherwise do not generate interest within each single observatory, or even reveal new sources.

Because neutrinos travel with nearly the speed of the light, a real-time or near real-time alert system based on neutrinos (with a good angular resolution) is possible. It is vital for follow-ups for some high energy transient sources that are time-dependent with the flux quickly varying. For example, a real-time neutrino alert will be able to point to a direction for space electromagnetic observatories that have a small sky coverage (e.g. Fermi-LAT) to conduct their search in a timely fashion. 

#### KM3NeT Multi-Messenger Neutrino Alerts

With the Southern sky including the Galactic Center in view and a good angular resolution, KM3NeT will contribute greatly to the multi-messenger community. For a detailed description of the detector, see [the detector page](Detector.md).


* For the search of neutrinos via event reconstructions based on (causally coincident) lit-up DOMs, focusing on high energy neutrinos, such as astrophysical neutrinos, KM3NeT will be able to send/receive alerts from/to the multi-messenger community: 

    1. to receive external alerts, i.e. alerts generated by external partner experiments (e.g. gravitational waves alerts from LIGO/Virgo, neutrino alerts from other neutrino experiments) via [GCN](https://gcn.gsfc.nasa.gov/) and search for correlated neutrinos in KM3NeT. 
    2. to send neutrino alerts (to GCN) that are observed in KM3NeT, including multiplet alerts, possible astrophysical neutrinos, any correlated neutrinos is found in the above mentioned correlation search. The alerts will be used for external partner experiments to conduct their correlation search/follow-up.


* For the search of MeV core-collapse supernova neutrinos, each KM3NeT DOM acts as a detector. A CCSN neutrino interaction leads to higher counting rates of individual PMTs and an increase of the number of coincident lit-up PMTs in the same optical module. Its search entails a different method from the usual neutrino event reconstruction route, and it has a separate alert system called the [SuperNova Early Warning System](https://snews.bnl.gov/), so the KM3NeT supernova alerts are not discussed in here. KM3NeT is already connected to SNEWS. 

#### KM3NeT Alert Types

The alert types include: 

* MeV Core-Collapse Supernova alerts (SNEWS), already online currently.
* Multiplet alerts: Multiple neutrinos from one source within some time window (this suggests a potential neutrino source).
* High-Energy Neutrino alerts. Potential neutrinos from astrophysical sources (The higher the energy, the higher the probability of it being of astrophysical origin).
* Any neutrinos correlated with external alerts.
* Other alerts to be defined, or more subcategories divided from the High-Energy Neutrino alerts if necessary (e.g. track HE, cascade HE alerts).

For alert data formatting and sending, see [the dataformat definition](Dataformats.md#multimessenger-alerts).

### Sea Science

#### Environmental data

The KM3NeT research infrastructure will also house instrumentation for Earth and Sea sciences for long-term and on-line monitoring of the deep-sea environment. Until now, measurements in the deep sea are typically performed by deploying and recovering autonomous devices that record data over periods of months to years. This method is severely constrained by bandwidth limitations, by the absence of real-time interaction with the measurement devices and by the delayed access to the data. A cabled deep-sea marine observatory, like KM3NeT, remedies these disadvantages by essentially providing a power socket and high bandwidth Ethernet connection at the bottom of the sea. This is an important and unique opportunity for performing deep-sea research in the fields of marine biology, oceanography, environmental sciences and geosciences. To this end, both the French and Italian KM3NeT sites are nodes of the European Multidisciplinary Seafloor and water column Observatory [EMSO](http://emso.eu).

EMSO sea science instrumentation modules will host sensors that provide real-time monitoring of a plethora of environmental parameters including temperature, pressure, conductivity, oxygen concentration, turbidity and sea current. Additional instrumentation including a benthic crawler, a seismograph, a deep-sea Germanium gamma detector and a high-speed, single-photon [video camera for bioluminescence studies](https://www.appec.org/news/km3net-is-growing-recent-deployment-in-the-mediterranean-sea) will also be installed. Furthermore, the KM3NeT optical modules themselves provide invaluable data on deep-sea bioluminescence and bioacoustic monitoring of the local cetacean populations. For example, acoustic signals from whales and dolphins can be detected with the [acoustic sensors](https://www.researchitaly.it/en/projects/big-electronic-ears-spy-on-sperm-whales-in-the-mediterranean-sea/). An other example is the possibility to use the optical fibres in the main electro-optical cables, that run for many tens of kilometre along the seafloor, for [seismological studies](https://eartharxiv.org/ekrfy).

#### Acoustic data

The telescope is also equipped with acoustic sensors: 1 piezo-electric ceramic sensor is installed in each DOM, 1 hydrophone on each DU base and on the junction boxes of the seafloor network. Main purpose of these sensors is to provide real time positioning of each DOM with cm accuracy. The hydrophone sensitivity (ominidirectional) is about -173 dB re 1V/uPa over the frequency band between few tens Hz and 70 kHz, that makes this sensor also suitable for interdisciplinary studies. 

The default KM3NeT DAQ has been designed to identify only the (known) acoustic signals emitted by a long baseline of acoustic sensors among the full data stream (Figure 2). A further implementation of the DAQ isforeseen in the future, permitting on-line analysis, display and recording of the underwater noise spectrum through a dedicated channel. A large number of use cases has been identified, as described [in this document](https://www.km3net.org/wp-content/uploads/2020/02/D8.1-KM3NeT-rules-of-access-for-external-users.pdf).

![Acoustic data acquisition system, from [2]](/figures/Acoustic_data.png)

At this stage, the unfiltered acoustic data can be made available directly from the ADF, which is provided in several formats through a REST-API on a data server integrated in the acoustic data processing system of KM3NeT.

## Detector

The KM3NeT Research Infrastructure will consist of a network of deep-sea neutrino detectors in the Mediterranean Sea with user ports for Earth and Sea sciences.

The KM3NeT neutrino detectors employ the same technology and neutrino detection principle, namely a three-dimensional array of photosensors that is used to detect Cherenkov light produced by relativistic particles emerging from neutrino interactions. From the arrival time of the Cherenkov photons (~nanosecond precision) and the position of the sensors (~10cm precision), the energy and direction of the incoming neutrino, as well as other parameters of the neutrino interaction, can be reconstructed. The main difference between different detector designs are the density of photosensors, which is optimised for the study of neutrinos in the few-GeV (ORCA) and TeV-PeV energy range (ARCA), respectively.

A key technology of the KM3NeT detectors is the Digital Optical Module (DOM), a pressure-resistant glass sphere housing 31 small 3-inch photo-multiplier tubes (PMTs), their associated electronics and calibration devices. The segmented photo-cathode of the multi-PMT design allows for uniform angular coverage, single-photon counting capabilities and directional information on the photon arrival direction. The DOMs are distributed in space along flexible strings, one end of which is fixed to the sea floor and the other end is held close to vertical by a submerged buoy. Each string comprises 18 DOMs. The strings are connected to junction boxes that provide connections for power and data transmission. 

A collection of 115 strings forms a single KM3NeT building block. The modular design allows building blocks with different spacings between strings/DOMs, in order to target different neutrino energies. In the KM3NeT Phase-2.0, three building blocks are foreseen: two KM3NeT/ARCA blocks, with a large spacing to target astrophysical neutrinos at TeV energies and above; and one KM3NeT/ORCA block, to target atmospheric neutrinos in the few-GeV range.

The ARCA (Astroparticle Research with Cosmics in the Abyss) detector is being installed at the KM3NeT-It site, 80km offshore the Sicilian coast offshore to Capo Passero (Italy) at a sea bottom depth of about 3450m. About 1 km^3 of seawater will be instrumented with ∼130000 PMTs.  The ORCA (Oscillation Research with Cosmics in the Abyss) detector is being installed at the KM3NeT-Fr site, 40km offshore Toulon (France) at a sea bottom depth of about 2450m. A volume of about 8 Mton is instrumented with ∼65000 PMTs. 

Technical details on the detector design are given in [1].

### Data Acquisition

The readout of the KM3NeT detector is based on the 'all-data-to-shore' concept, in which all analogue signals from the PMTs that pass a reference threshold are digitised. This data contain the time at which the analogue pulse crosses the threshold level, the time that the pulse remains above the threshold level (known as time-over-threshold, or ToT), and the PMT address. This is typically called a *hit*. All digital data (about 25 Gb/s per building block) are sent to a computing farm onshore where they are processed in real time. 
The recorded data is dominated by optical background noise from Cherenkov light from K40 decays in the seawater as well as bioluminescence from luminescent organisms in the deep sea. Events of scientific interest are filtered from the background using designated software, which exploit the time-position correlations following from causality. To maintain all available information for the offline analyses, each event contains a snapshot of all the data in the detector during the event. 

For calibration purposes summary data is written out, containing the count rates of all PMTs in the detector (with a sampling frequency of 10Hz). This information is used in the simulations as well as in the reconstruction to take into account the actual status and optical background conditions of the detector.

In parallel to the optical data, acoustic data and instrument data are recorded. The main purpose is position calibration of the DOMs, which is necessary as the detector elements can move under the influence of sea currents. The acoustic data includes the processed output from the piezo sensors in the DOMs and from the hydrophones in the base modules of the strings. The instrument data includes the processed output from the compasses, temperature sensors and humidity sensors inside the DOMs.

During operation the continuous data stream sent by the detector is split into small time intervals, called *runs*, with typical durations of a few hours. This is done for practical reasons of the data acquisition. In addition, this procedure allows to selected a set of run periods with high-quality data based on the monitored detector status, environmental conditions and data quality. The calibration for timing, positioning and photon detection efficiency is done offline using the calibration data. 

## Detector and event simulations

In order to evaluate and test physical models of neutrino interactions and productions, a huge variety of simulations need to be performed and compared to the data taken with the KM3NeT detectors. Several parts of the detector are modelled including photomultiplier tube characteristics, complex electronic components that process signals of those in sub-nanosecond time regimes, the high throughput data distribution over heterogeneous networks and also physical properties of the environment (like seawater, atmosphere...) and the materials used. All these are carefully taken into account when simulating the overall detector response of particle interactions.

The first level of event simulation starts with the incoming primary particle: neutrinos produced in cosmic events or for example atmospheric neutrinos and muons produced by cosmic radiation in the Earth's atmosphere. These primary particles eventually trigger events in the detector after a usually large chain of interactions. The second level of the simulation chain takes care of the propagation of these particles and additional particles produced along their way through the atmosphere, Earth and seawater - depending on their travel path - until they reach the detector volume. In the final step, the light produced by the particles is simulated and propagated to the highly sensitive optical modules where they are digitised and passed to the above mentioned hardware
response simulation.

The full event simulation is implemented in a run-by-run simulation strategy building on the so called data runs as standard data taking intervals of several hours. The detector response is simulated individually for these periods. Since large statistics are required for precise analyses, the simulation data will significantly exceed the real data in volume.

### Event simulation derivatives as service

As handling these large data sets is impractical for inter-experimental studies, but the information is crucial for the interpretability of the data, parameterized distributions of relevant observables need to be derived from the simulation data sets and offered as services. Even in absence of significant neutrino measurements in the construction phase of KM3NeT, offering sensitivity estimates for given models is beneficial for the development of common research goals and the development of a corresponding open service is currently under investigation.

